pinax-boxes
===========

An app for including boxes of admin-controllable content in templates.

.. image:: http://slack.pinaxproject.com/badge.svg
   :target: http://slack.pinaxproject.com/

.. image:: https://img.shields.io/travis/pinax/pinax-boxes.svg
   :target: https://travis-ci.org/pinax/pinax-boxes

.. image:: https://img.shields.io/coveralls/pinax/pinax-boxes.svg
   :target: https://coveralls.io/r/pinax/pinax-boxes

.. image:: https://img.shields.io/pypi/dm/pinax-boxes.svg
   :target:  https://pypi.python.org/pypi/pinax-boxes/

.. image:: https://img.shields.io/pypi/v/pinax-boxes.svg
   :target:  https://pypi.python.org/pypi/pinax-boxes/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target:  https://pypi.python.org/pypi/pinax-boxes/


Pinax
------

Pinax is an open-source platform built on the Django Web Framework. It is an ecosystem of reusable Django apps, themes, and starter project templates.
This collection can be found at http://pinaxproject.com.


Running the Tests
-------------------

    ::

       $ pip install detox
       $ detox


Documentation
---------------

The Pinax documentation is available at http://pinaxproject.com/pinax/.


Code of Conduct
----------------

In order to foster a kind, inclusive, and harassment-free community, the Pinax Project has a code of conduct, which can be found here  http://pinaxproject.com/pinax/code_of_conduct/.


Pinax Project Blog and Twitter
--------------------------------

For updates and news regarding the Pinax Project, please follow us on Twitter at @pinaxproject and check out our blog http://blog.pinaxproject.com.
